@@ -18,9 +18,8 @@
         <translation>MX Ripara Boot</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
         <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation>MX Ripara Boot è un utility che può servire per reinstallare GRUB sul Registro di Inizializzazione del Disco (MBR) o sul  Registro di Inizializzazione della Partizione root o PBR. Permette di riscrivere il file di configurazione di GRUB, fare il back up e ripristinare MBR o PBR.</translation>
+        <translation type="vanished">MX Ripara Boot è un utility che può servire per reinstallare GRUB sul Registro di Inizializzazione del Disco (MBR) o sul  Registro di Inizializzazione della Partizione root o PBR. Permette di riscrivere il file di configurazione di GRUB, fare il back up e ripristinare MBR o PBR.</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
@@ -33,9 +32,18 @@
         <translation>Fare il backup dell&apos; MBR o del PBR (solo per legacy boot)</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader</source>
-        <translation>Reinstallare GRUB (il programma che gestisce il boot del computer)</translation>
+        <translation type="vanished">Reinstallare GRUB (il programma che gestisce il boot del computer)</translation>
+    </message>
+    <message>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mxbootrepair.ui" line="86"/>
+        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="96"/>
@@ -65,7 +73,7 @@
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="147"/>
-        <location filename="../mxbootrepair.ui" line="418"/>
+        <location filename="../mxbootrepair.ui" line="417"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
@@ -117,43 +125,43 @@
         <translation>Info...</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="460"/>
+        <location filename="../mxbootrepair.ui" line="459"/>
         <source>Display help </source>
         <translation>Visualizza la guida</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="463"/>
+        <location filename="../mxbootrepair.ui" line="462"/>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="471"/>
+        <location filename="../mxbootrepair.ui" line="469"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="512"/>
+        <location filename="../mxbootrepair.ui" line="510"/>
         <source>Cancel any changes then quit</source>
         <translation>Cancella tutte le modifiche quando chiudi</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="515"/>
+        <location filename="../mxbootrepair.ui" line="513"/>
         <location filename="../mxbootrepair.cpp" line="451"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="523"/>
+        <location filename="../mxbootrepair.ui" line="520"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="542"/>
+        <location filename="../mxbootrepair.ui" line="539"/>
         <source>Apply any changes</source>
         <translation>Applica tutti i cambiamenti</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="545"/>
+        <location filename="../mxbootrepair.ui" line="542"/>
         <location filename="../mxbootrepair.cpp" line="78"/>
         <source>Apply</source>
         <translation>Applica</translation>
@@ -161,7 +169,7 @@
     <message>
         <location filename="../mxbootrepair.cpp" line="96"/>
         <source>GRUB is being installed on %1 device.</source>
-        <translation type="unfinished"></translation>
+        <translation>GRUB è in fase d&apos;installazione sulla periferica %1</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="111"/>
@@ -195,12 +203,12 @@ Prego, verifica nuovamente la posizione selezionata.</translation>
     <message>
         <location filename="../mxbootrepair.cpp" line="152"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
-        <translation type="unfinished"></translation>
+        <translation>Il file di configurazione di GRUB (grub.cfg) viene ricostituito.</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="186"/>
         <source>Backing up MBR or PBR from %1 device.</source>
-        <translation type="unfinished"></translation>
+        <translation>Backup dell&apos; MBR o del PBR dall&apos;unità %1.</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="241"/>
@@ -241,7 +249,7 @@ Sei sicuro?</translation>
     <message>
         <location filename="../mxbootrepair.cpp" line="247"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ripristino dell&apos; MBR/PBR da backup sull&apos;unità %1</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="267"/>
@@ -271,17 +279,17 @@ Sei sicuro?</translation>
     <message>
         <location filename="../mxbootrepair.cpp" line="387"/>
         <source>Select GRUB location</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona la posizione di GRUB</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="398"/>
         <source>Select Item to Back Up</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona l&apos;elemento da sottoporre a backup</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="405"/>
         <source>Select Item to Restore</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona l&apos;elemento da ripristinare</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="416"/>
