@@ -17,11 +17,6 @@
         <source>MX Boot Repair</source>
         <translation>MX paleidimo taisymas</translation>
     </message>
-    <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
         <source>What would you like to do?</source>
@@ -33,9 +28,18 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader</source>
-        <translation>Iš naujo įdiegti GRUB paleidyklę</translation>
+        <translation type="vanished">Iš naujo įdiegti GRUB paleidyklę</translation>
+    </message>
+    <message>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mxbootrepair.ui" line="86"/>
+        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="96"/>
@@ -65,7 +69,7 @@
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="147"/>
-        <location filename="../mxbootrepair.ui" line="418"/>
+        <location filename="../mxbootrepair.ui" line="417"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
@@ -117,43 +121,43 @@
         <translation>Apie...</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="460"/>
+        <location filename="../mxbootrepair.ui" line="459"/>
         <source>Display help </source>
         <translation>Rodyti žinyną</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="463"/>
+        <location filename="../mxbootrepair.ui" line="462"/>
         <source>Help</source>
         <translation>Žinynas</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="471"/>
+        <location filename="../mxbootrepair.ui" line="469"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="512"/>
+        <location filename="../mxbootrepair.ui" line="510"/>
         <source>Cancel any changes then quit</source>
         <translation>Atsisakyti bet kokių pakeitimų, o tuomet išeiti</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="515"/>
+        <location filename="../mxbootrepair.ui" line="513"/>
         <location filename="../mxbootrepair.cpp" line="451"/>
         <source>Cancel</source>
         <translation>Atsisakyti</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="523"/>
+        <location filename="../mxbootrepair.ui" line="520"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="542"/>
+        <location filename="../mxbootrepair.ui" line="539"/>
         <source>Apply any changes</source>
         <translation>Taikyti bet kokius pakeitimus</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="545"/>
+        <location filename="../mxbootrepair.ui" line="542"/>
         <location filename="../mxbootrepair.cpp" line="78"/>
         <source>Apply</source>
         <translation>Taikyti</translation>
